@@ -3,8 +3,9 @@ Main interface for ec2 service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.ec2 import (
+    from mypy_boto3_ec2 import (
         BundleTaskCompleteWaiter,
         Client,
         ConversionTaskCancelledWaiter,
@@ -128,7 +129,7 @@ Usage::
         VpcPeeringConnectionExistsWaiter,
         VpnConnectionAvailableWaiter,
         VpnConnectionDeletedWaiter,
-        )
+    )
 
     session = boto3.Session()
 
@@ -258,8 +259,9 @@ Usage::
     get_transit_gateway_route_table_propagations_paginator: GetTransitGatewayRouteTablePropagationsPaginator = client.get_paginator("get_transit_gateway_route_table_propagations")
     search_local_gateway_routes_paginator: SearchLocalGatewayRoutesPaginator = client.get_paginator("search_local_gateway_routes")
     search_transit_gateway_multicast_groups_paginator: SearchTransitGatewayMulticastGroupsPaginator = client.get_paginator("search_transit_gateway_multicast_groups")
+    ```
 """
-from mypy_boto3_ec2.client import EC2Client as Client, EC2Client
+from mypy_boto3_ec2.client import EC2Client, EC2Client as Client
 from mypy_boto3_ec2.paginator import (
     DescribeByoipCidrsPaginator,
     DescribeCapacityReservationsPaginator,
@@ -350,8 +352,8 @@ from mypy_boto3_ec2.paginator import (
     SearchTransitGatewayMulticastGroupsPaginator,
 )
 from mypy_boto3_ec2.service_resource import (
-    EC2ServiceResource as ServiceResource,
     EC2ServiceResource,
+    EC2ServiceResource as ServiceResource,
 )
 from mypy_boto3_ec2.waiter import (
     BundleTaskCompleteWaiter,
